package com.yaohun.consumereward.manage;

import com.yaohun.consumereward.data.PlayerData;

import java.util.HashMap;

/**
 * 玩家管理器类，用于管理游戏中的玩家数据
 */
public class PlayerManager {

    /**
     * 存储玩家数据的映射表，键为玩家名称，值为玩家数据对象
     */
    private HashMap<String, PlayerData> playerDataMap = new HashMap<>();

    /**
     * 获取玩家数据如果玩家数据不存在，则创建新的玩家数据对象
     *
     * @param playerName 玩家名称，用于标识玩家数据
     * @return 玩家数据对象，如果之前不存在则返回新创建的玩家数据对象
     */
    public PlayerData getPlayerData(String playerName) {
        // 检查映射表中是否已存在该玩家的玩家数据
        if(!playerDataMap.containsKey(playerName)){
            // 如果不存在，创建新的玩家数据对象
            PlayerData playerData = new PlayerData(playerName);
            // 将新的玩家数据对象添加到映射表中
            playerDataMap.put(playerName, playerData);
            // 返回新的玩家数据对象
            return playerData;
        }
        // 如果存在，直接返回该玩家的玩家数据对象
        return playerDataMap.get(playerName);
    }
}

