package com.yaohun.consumereward.util;

import com.yaohun.consumereward.config.Config;
import org.bukkit.Sound;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

/**
 * 消息工具类，用于向命令发送者发送消息
 * 提供了向Minecraft服务器中的玩家或其他命令发送者发送消息的功能
 */
public class MessageUtil {

    /**
     * 向指定的命令发送者发送消息
     * 如果发送者是玩家，使用玩家对象的sendMessage方法发送；
     * 否则直接使用命令发送者的sendMessage方法
     *
     * @param sender  命令发送者对象（可以是玩家或控制台）
     * @param message 要发送的消息内容
     */
    public static void sendMessage(CommandSender sender, String message) {
        if(sender instanceof Player){
            Player player = (Player) sender;
            player.sendMessage(message);
        } else {
            sender.sendMessage(message);
        }
    }

    /**
     * 向指定的命令发送者发送消息并播放音效
     * 如果发送者是玩家，则还会播放指定的音效
     *
     * @param sender 命令发送者，可以是玩家或控制台等
     * @param message 要发送的消息文本
     * @param sound 要播放的音效
     */
    public static void sendMessage(CommandSender sender, String message, Sound sound) {
        // 判断发送者是否为玩家，以便播放音效
        if(sender instanceof Player){
            Player player = (Player) sender;
            player.sendMessage(message);
            player.playSound(player.getLocation(), sound, 0.5f, 1.2f);
        } else {
            sender.sendMessage(message);
        }
    }

    /**
     * 根据语言键向指定的命令发送者发送消息并播放音效
     * 首先从配置文件中获取对应语言键的消息文本，然后发送给发送者
     * 如果发送者是玩家，则还会播放指定的音效
     *
     * @param sender 命令发送者，可以是玩家或控制台等
     * @param langKey 语言键，用于从配置文件中获取消息文本
     * @param sound 要播放的音效
     */
    public static void sendMessageKey(CommandSender sender, String langKey, Sound sound) {
        String message = Config.langData.getMessage(langKey);
        // 判断发送者是否为玩家，以便播放音效
        if(sender instanceof Player){
            Player player = (Player) sender;
            player.sendMessage(message);
            player.playSound(player.getLocation(), sound, 0.5f, 1.2f);
        } else {
            sender.sendMessage(message);
        }
    }

}
